/****************************************************************************
** Meta object code from reading C++ file 'localcalendar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kongress-26.07.80/src/localcalendar.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'localcalendar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13LocalCalendarE_t {};
} // unnamed namespace

template <> constexpr inline auto LocalCalendar::qt_create_metaobjectdata<qt_meta_tag_ZN13LocalCalendarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LocalCalendar",
        "memorycalendarChanged",
        "",
        "calendarIdChanged",
        "calendarTzIdChanged",
        "calendarUrlChanged",
        "calendarTypeChanged",
        "categoriesChanged",
        "eventsChanged",
        "calendarControllerChanged",
        "busyDownladingChanged",
        "onlineCalendarReady",
        "calendarId",
        "setBusyStatus",
        "downlading",
        "createCalendar",
        "loadOnlineCalendar",
        "calendarTzId",
        "calendarUrl",
        "calendarType",
        "memorycalendar",
        "QSharedPointer<KCalendarCore::MemoryCalendar>",
        "categories",
        "calendarController",
        "CalendarController*",
        "busyDownlading"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'memorycalendarChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarIdChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarTzIdChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarUrlChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarTypeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoriesChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eventsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarControllerChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'busyDownladingChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onlineCalendarReady'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setBusyStatus'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'createCalendar'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'loadOnlineCalendar'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'calendarId'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'calendarTzId'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'calendarUrl'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'calendarType'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'memorycalendar'
        QtMocHelpers::PropertyData<QSharedPointer<KCalendarCore::MemoryCalendar>>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'categories'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags, 5),
        // property 'calendarController'
        QtMocHelpers::PropertyData<CalendarController*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'busyDownlading'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LocalCalendar, qt_meta_tag_ZN13LocalCalendarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LocalCalendar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LocalCalendarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LocalCalendarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13LocalCalendarE_t>.metaTypes,
    nullptr
} };

void LocalCalendar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LocalCalendar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->memorycalendarChanged(); break;
        case 1: _t->calendarIdChanged(); break;
        case 2: _t->calendarTzIdChanged(); break;
        case 3: _t->calendarUrlChanged(); break;
        case 4: _t->calendarTypeChanged(); break;
        case 5: _t->categoriesChanged(); break;
        case 6: _t->eventsChanged(); break;
        case 7: _t->calendarControllerChanged(); break;
        case 8: _t->busyDownladingChanged(); break;
        case 9: _t->onlineCalendarReady((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setBusyStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->createCalendar(); break;
        case 12: _t->loadOnlineCalendar(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::memorycalendarChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::calendarIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::calendarTzIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::calendarUrlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::calendarTypeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::categoriesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::eventsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::calendarControllerChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (LocalCalendar::*)()>(_a, &LocalCalendar::busyDownladingChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSharedPointer<KCalendarCore::MemoryCalendar> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->calendarId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->calendarTzId(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->calendarUrl(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->calendarType(); break;
        case 4: *reinterpret_cast<QSharedPointer<KCalendarCore::MemoryCalendar>*>(_v) = _t->memorycalendar(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->categories(); break;
        case 6: *reinterpret_cast<CalendarController**>(_v) = _t->calendarController(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->busyDownlading(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCalendarId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setCalendarTzId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setCalendarUrl(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setCalendarType(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setCalendarController(*reinterpret_cast<CalendarController**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LocalCalendar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LocalCalendar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LocalCalendarE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LocalCalendar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void LocalCalendar::memorycalendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LocalCalendar::calendarIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LocalCalendar::calendarTzIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LocalCalendar::calendarUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LocalCalendar::calendarTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LocalCalendar::categoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void LocalCalendar::eventsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void LocalCalendar::calendarControllerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void LocalCalendar::busyDownladingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
