/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kongressac.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kongressacadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KongressacAdaptor
 */

KongressacAdaptor::KongressacAdaptor(CalAlarmClient *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KongressacAdaptor::~KongressacAdaptor()
{
    // destructor
}

int KongressacAdaptor::active()
{
    // handle method call org.kde.kongressac.active
    return parent()->active();
}

void KongressacAdaptor::forceAlarmCheck()
{
    // handle method call org.kde.kongressac.forceAlarmCheck
    parent()->forceAlarmCheck();
}

void KongressacAdaptor::quit()
{
    // handle method call org.kde.kongressac.quit
    parent()->quit();
}

void KongressacAdaptor::scheduleAlarmCheck()
{
    // handle method call org.kde.kongressac.scheduleAlarmCheck
    parent()->scheduleAlarmCheck();
}


#include "moc_kongressacadaptor.cpp"
