/****************************************************************************
** Meta object code from reading C++ file 'conference.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kongress-26.07.80/src/conference.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'conference.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ConferenceE_t {};
} // unnamed namespace

template <> constexpr inline auto Conference::qt_create_metaobjectdata<qt_meta_tag_ZN10ConferenceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Conference",
        "id",
        "name",
        "description",
        "icalUrl",
        "days",
        "venueImageUrl",
        "venueLatitude",
        "venueLongitude",
        "venueOsmUrl",
        "timeZoneId",
        "indoorMapBoundingBox",
        "QRectF",
        "indoorMapStyle",
        "indoorMapExtraContent",
        "indoorRoutingEnabled",
        "hasVenueCoordinate",
        "hasVenueIndoorMap"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'icalUrl'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'days'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'venueImageUrl'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'venueLatitude'
        QtMocHelpers::PropertyData<double>(7, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'venueLongitude'
        QtMocHelpers::PropertyData<double>(8, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'venueOsmUrl'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'timeZoneId'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'indoorMapBoundingBox'
        QtMocHelpers::PropertyData<QRectF>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'indoorMapStyle'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'indoorMapExtraContent'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'indoorRoutingEnabled'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasVenueCoordinate'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hasVenueIndoorMap'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Conference, qt_meta_tag_ZN10ConferenceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Conference::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ConferenceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ConferenceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ConferenceE_t>.metaTypes,
    nullptr
} };

void Conference::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Conference *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->icalUrl(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->days(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->venueImageUrl(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->venueLatitude(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->venueLongitude(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->venueOsmUrl(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->timeZoneId(); break;
        case 10: *reinterpret_cast<QRectF*>(_v) = _t->m_indoorMapBbox; break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->m_indoorMapStyle; break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->m_indoorExtraContent; break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->m_indoorRoutingEnabled; break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->hasVenueCoordinate(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->hasVenueIndoorMap(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 10: QtMocHelpers::setProperty(_t->m_indoorMapBbox, *reinterpret_cast<QRectF*>(_v)); break;
        case 11: QtMocHelpers::setProperty(_t->m_indoorMapStyle, *reinterpret_cast<QString*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->m_indoorExtraContent, *reinterpret_cast<QString*>(_v)); break;
        case 13: QtMocHelpers::setProperty(_t->m_indoorRoutingEnabled, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
